@@ -1,17 +1,8 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 # -*- coding: utf-8 -*-
-
-"""
-    Change directory to provide relative paths for doctests
-    >>> import os
-    >>> filepath = os.path.dirname(os.path.realpath(__file__ ))
-    >>> datadir = os.path.realpath(os.path.join(filepath,
-    ...                            '../../testing/data'))
-    >>> os.chdir(datadir)
-
-"""
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 import os.path as op
 
@@ -20,31 +11,57 @@ from .base import MRTrix3BaseInputSpec, MRTrix3Base
 
 
 class TractographyInputSpec(MRTrix3BaseInputSpec):
-    sph_trait = traits.Tuple(traits.Float, traits.Float, traits.Float,
-                             traits.Float, argstr='%f,%f,%f,%f')
+    sph_trait = traits.Tuple(
+        traits.Float,
+        traits.Float,
+        traits.Float,
+        traits.Float,
+        argstr='%f,%f,%f,%f')
 
-    in_file = File(exists=True, argstr='%s', mandatory=True, position=-2,
-                   desc='input file to be processed')
+    in_file = File(
+        exists=True,
+        argstr='%s',
+        mandatory=True,
+        position=-2,
+        desc='input file to be processed')
 
-    out_file = File('tracked.tck', argstr='%s', mandatory=True, position=-1,
-                    usedefault=True, desc='output file containing tracks')
+    out_file = File(
+        'tracked.tck',
+        argstr='%s',
+        mandatory=True,
+        position=-1,
+        usedefault=True,
+        desc='output file containing tracks')
 
     algorithm = traits.Enum(
-        'iFOD2', 'FACT', 'iFOD1', 'Nulldist', 'SD_Stream', 'Tensor_Det',
-        'Tensor_Prob', usedefault=True, argstr='-algorithm %s',
+        'iFOD2',
+        'FACT',
+        'iFOD1',
+        'Nulldist',
+        'SD_Stream',
+        'Tensor_Det',
+        'Tensor_Prob',
+        usedefault=True,
+        argstr='-algorithm %s',
         desc='tractography algorithm to be used')
 
     # ROIs processing options
     roi_incl = traits.Either(
-        File(exists=True), sph_trait, argstr='-include %s',
+        File(exists=True),
+        sph_trait,
+        argstr='-include %s',
         desc=('specify an inclusion region of interest, streamlines must'
               ' traverse ALL inclusion regions to be accepted'))
     roi_excl = traits.Either(
-        File(exists=True), sph_trait, argstr='-exclude %s',
+        File(exists=True),
+        sph_trait,
+        argstr='-exclude %s',
         desc=('specify an exclusion region of interest, streamlines that'
               ' enter ANY exclude region will be discarded'))
     roi_mask = traits.Either(
-        File(exists=True), sph_trait, argstr='-mask %s',
+        File(exists=True),
+        sph_trait,
+        argstr='-mask %s',
         desc=('specify a masking region of interest. If defined,'
               'streamlines exiting the mask will be truncated'))
 
@@ -93,7 +110,9 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
         desc=('track from the seed point in one direction only '
               '(default is to track in both directions)'))
     init_dir = traits.Tuple(
-        traits.Float, traits.Float, traits.Float,
+        traits.Float,
+        traits.Float,
+        traits.Float,
         argstr='-initdirection %f,%f,%f',
         desc=('specify an initial direction for the tracking (this '
               'should be supplied as a vector of 3 comma-separated values'))
@@ -105,7 +124,8 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
         argstr='-power %d',
         desc=('raise the FOD to the power specified (default is 1/nsamples)'))
     n_samples = traits.Int(
-        4, argstr='-samples %d',
+        4, usedefault=True,
+        argstr='-samples %d',
         desc=('set the number of FOD samples to take per step for the 2nd '
               'order (iFOD2) method'))
     use_rk4 = traits.Bool(
@@ -122,12 +142,13 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
 
     # Anatomically-Constrained Tractography options
     act_file = File(
-        exists=True, argstr='-act %s',
+        exists=True,
+        argstr='-act %s',
         desc=('use the Anatomically-Constrained Tractography framework during'
               ' tracking; provided image must be in the 5TT '
               '(five - tissue - type) format'))
-    backtrack = traits.Bool(argstr='-backtrack',
-                            desc='allow tracks to be truncated')
+    backtrack = traits.Bool(
+        argstr='-backtrack', desc='allow tracks to be truncated')
 
     crop_at_gmwmi = traits.Bool(
         argstr='-crop_at_gmwmi',
@@ -136,18 +157,26 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
 
     # Tractography seeding options
     seed_sphere = traits.Tuple(
-        traits.Float, traits.Float, traits.Float, traits.Float,
-        argstr='-seed_sphere %f,%f,%f,%f', desc='spherical seed')
-    seed_image = File(exists=True, argstr='-seed_image %s',
-                      desc='seed streamlines entirely at random within mask')
+        traits.Float,
+        traits.Float,
+        traits.Float,
+        traits.Float,
+        argstr='-seed_sphere %f,%f,%f,%f',
+        desc='spherical seed')
+    seed_image = File(
+        exists=True,
+        argstr='-seed_image %s',
+        desc='seed streamlines entirely at random within mask')
     seed_rnd_voxel = traits.Tuple(
-        File(exists=True), traits.Int(),
+        File(exists=True),
+        traits.Int(),
         argstr='-seed_random_per_voxel %s %d',
         xor=['seed_image', 'seed_grid_voxel'],
         desc=('seed a fixed number of streamlines per voxel in a mask '
               'image; random placement of seeds in each voxel'))
     seed_grid_voxel = traits.Tuple(
-        File(exists=True), traits.Int(),
+        File(exists=True),
+        traits.Int(),
         argstr='-seed_grid_per_voxel %s %d',
         xor=['seed_image', 'seed_rnd_voxel'],
         desc=('seed a fixed number of streamlines per voxel in a mask '
@@ -155,15 +184,19 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
               'is per axis; so a grid_size of 3 results in 27 seeds per'
               ' voxel)'))
     seed_rejection = File(
-        exists=True, argstr='-seed_rejection %s',
+        exists=True,
+        argstr='-seed_rejection %s',
         desc=('seed from an image using rejection sampling (higher '
               'values = more probable to seed from'))
     seed_gmwmi = File(
-        exists=True, argstr='-seed_gmwmi %s', requires=['act_file'],
+        exists=True,
+        argstr='-seed_gmwmi %s',
+        requires=['act_file'],
         desc=('seed from the grey matter - white matter interface (only '
               'valid if using ACT framework)'))
     seed_dynamic = File(
-        exists=True, argstr='-seed_dynamic %s',
+        exists=True,
+        argstr='-seed_dynamic %s',
         desc=('determine seed points dynamically using the SIFT model '
               '(must not provide any other seeding mechanism). Note that'
               ' while this seeding mechanism improves the distribution of'
@@ -175,19 +208,20 @@ class TractographyInputSpec(MRTrix3BaseInputSpec):
               'algorithm should attempt to find an appropriate tracking'
               ' direction from a given seed point'))
     out_seeds = File(
-        'out_seeds.nii.gz', argstr='-output_seeds %s',
+        'out_seeds.nii.gz', usedefault=True,
+        argstr='-output_seeds %s',
         desc=('output the seed location of all successful streamlines to'
               ' a file'))
 
 
 class TractographyOutputSpec(TraitedSpec):
     out_file = File(exists=True, desc='the output filtered tracks')
-    out_seeds = File(desc=('output the seed location of all successful'
-                           ' streamlines to a file'))
+    out_seeds = File(
+        desc=('output the seed location of all successful'
+              ' streamlines to a file'))
 
 
 class Tractography(MRTrix3Base):
-
     """
     Performs streamlines tractography after selecting the appropriate
     algorithm.
@@ -228,7 +262,8 @@ class Tractography(MRTrix3Base):
     >>> tk.inputs.roi_mask = 'mask.nii.gz'
     >>> tk.inputs.seed_sphere = (80, 100, 70, 10)
     >>> tk.cmdline                               # doctest: +ELLIPSIS
-    'tckgen -algorithm iFOD2 -mask mask.nii.gz -seed_sphere \
+    'tckgen -algorithm iFOD2 -samples 4 -output_seeds out_seeds.nii.gz \
+-mask mask.nii.gz -seed_sphere \
 80.000000,100.000000,70.000000,10.000000 fods.mif tracked.tck'
     >>> tk.run()                                 # doctest: +SKIP
     """
